import { Component, OnInit , ChangeDetectionStrategy , Renderer2 } from '@angular/core';
import {FormControl, FormGroup, FormsModule, ReactiveFormsModule , Validators} from '@angular/forms';
import {MatIconModule} from '@angular/material/icon';
import {MatDividerModule} from '@angular/material/divider';
import {MatButtonModule} from '@angular/material/button';
import {provideNativeDateAdapter} from '@angular/material/core';
import {MatDatepickerModule} from '@angular/material/datepicker';
import {MatFormFieldModule} from '@angular/material/form-field';
import {MatInputModule} from '@angular/material/input';
import {MatSelectModule} from '@angular/material/select';
import {MatButtonToggleModule} from '@angular/material/button-toggle';
import {MatCheckboxModule} from '@angular/material/checkbox';
import {ConformidadHelper} from "./helper/conformidad.helper";
import {NgForOf} from "@angular/common";
import {MatCardModule} from '@angular/material/card';

interface tiposTrabajo {
  value: string;
  viewValue: string;
}

@Component({
  imports: [
    MatDatepickerModule,
    MatFormFieldModule,
    FormsModule,
    ReactiveFormsModule,
    MatSelectModule,
    MatInputModule,
    MatButtonToggleModule,
    MatCheckboxModule,
    NgForOf,
    MatCardModule,
    MatButtonModule,
    MatDividerModule,
    MatIconModule
  ],
  providers: [provideNativeDateAdapter()],
  selector: 'app-conformidad',
  standalone: true,
  templateUrl: './conformidad.componente.html',
  styleUrls: ['./conformidad.componente.css'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})

export class ConformidadComponent implements OnInit {

  listTipoTrabajo: tiposTrabajo[] = [
    {value: '1', viewValue: 'Instalaciòn-Revisión'},
    {value: '2', viewValue: 'Instalaciòn-Ampliación'},
    {value: '3', viewValue: 'Mantenimiento-Reparación'},
    {value: '4', viewValue: 'Mantenimiento-Remodelación'},
    {value: '5', viewValue: 'Reposición'},
    {value: '6', viewValue: 'Reinstalación'},

  ];

  // INICIALIZACION DEL RANGO DE FECHAS
  readonly range = new FormGroup({
    fechaInicio: new FormControl<Date | null>(null),
    fechaFin: new FormControl<Date | null>(null),
  })

  selected = 'option2';
  // INICIALIZACION DEL RANGO DE FECHAS


  // DATALIST
  personal_list: any = [];
  sede_list: any = [];
  // DATALIST

  // GROUPO DE FORMULARIO
  datos_personal = new FormGroup({
     tecnicoPersonal : new FormControl(null ,Validators.required),
     sedePersonal : new FormControl(null,Validators.required),
     areaPersonal : new FormControl<String | null>(null ,Validators.required),
     pasajePersonal : new FormControl(null ,Validators.required)
  });

  datos_servicio = new FormGroup({
    requerimientoServicio : new FormControl(null ,Validators.required),
    descripcionServicio : new FormControl(null ,Validators.required),
    causaServicio : new FormControl(null ,Validators.required),
    btnEvidenciaProblema : new FormControl(null ,Validators.required),
    btnEvidenciaSolucion : new FormControl(null ,Validators.required)
  });

  datos_trabajo = new FormGroup({
    tipoTrabajo : new FormControl(null ,Validators.required),
    descripcionTrabajo : new FormControl(null ,Validators.required)
  });

  datos_material = new FormGroup({
    materialSobrante : new FormControl(null ,Validators.required)
  });

  // GROUPO DE FORMULARIO

  constructor(
    private conformidadHelper: ConformidadHelper,
    private renderer: Renderer2
  ) {
    renderer.setStyle(document.body, 'background', 'var(--light-theme-bg)');
  }

  //ACCESOS RAPIDOS A GRUPOS DE FORMULARIOS

  accesoDP(){
    return this.datos_personal.controls;
  }

  //ACCESOS RAPIDOS A GRUPOS DE FORMULARIOS

  async ngOnInit(): Promise<void> {

    const [
      personal,
      sede
    ] = await Promise.all([
      this.conformidadHelper.cargarPersonal(),
      this.conformidadHelper.cargarSede(),
    ]);

    this.personal_list = personal;
    this.sede_list = sede;

    console.log(personal, sede);
  }

  onEventTecnico(event: any) { // IMPRIMER EL ÁREA DEL TÉCNICO AL SELECCIONARLO

    const areaControl = this.accesoDP().areaPersonal;
    const areaElemento = this.renderer.selectRootElement('[formControlName="areaPersonal"]');

    const codigoPer = event.value;
    const personal_list = this.personal_list;
    const personal_datos = personal_list.find((item: any) => item.codper === codigoPer);

    if(Object.keys(personal_datos).length  > 0){
      areaControl.setValue(personal_datos.descargo);
    }else{
      areaControl.setValue('Sin Cargo');
    }

    areaControl.updateValueAndValidity();
  }

  onBusquedaRequerimiento(event: any){

  }

}

